@@ -38,13 +38,12 @@ public:
 Q_SIGNALS:
     void enableButton(bool state);
 
-private Q_SLOTS:
+private:
     void slotTextChanged(const QString &);
 
-private:
-    KLineEdit *mCategoryLineEdit;
-    QCheckBox *mEnableCategory;
-    CategoryTypeComboBox *mCategoryType;
+    KLineEdit *mCategoryLineEdit = nullptr;
+    QCheckBox *mEnableCategory = nullptr;
+    CategoryTypeComboBox *mCategoryType = nullptr;
 };
 
 #endif // CONFIGURECUSTOMSETTINGWIDGET_H
